* Regression Analyses
* Please note the data files for this replication require Stata 13. 

capture program drop myregress
program define myregress

	clear
	set more off
	
	global control1 usaid         gdppc wbgi fhscore africa trade_i trade_e unvote_key
	global control2 usaid_imputed gdppc wbgi fhscore africa trade_i trade_e unvote_key
	global opt se noas br bd(3)
	
	if "`1'"=="Table1_Table2"{
	
		capture log close
		log using _output/`1'.log, replace
	
		use _data/replicationdata_2007-2010_log_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt replace
		estat endogenous
		estat firststage
		estat overid

		use _data/replicationdata_2007-2008_log_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		use _data/replicationdata_2009-2010_log_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		log close
		
	}
	
	
	else if "`1'"=="Table3"{
	
		foreach country in us ch fr ge in ja ru uk ownc {
	
			capture log close
			log using _output/`1'_`country'.log, replace
	
			use _data/replicationdata_2007-2010_log_dv, clear
			ivregress 2sls y_`country' (x=z_*) $control1, robust 
			outreg2 x using _output/`1'_`country'.txt, $opt replace

			use _data/replicationdata_2007-2008_log_dv, clear
			ivregress 2sls y_`country' (x=z_*) $control1, robust 
			outreg2 x using _output/`1'_`country'.txt, $opt append
	
			use _data/replicationdata_2009-2010_log_dv, clear
			ivregress 2sls y_`country' (x=z_*) $control1, robust 
			outreg2 x using _output/`1'_`country'.txt, $opt append
	
			log close
		}	
	
	}
	
	
	else if "`1'"=="TableA"{
	
		capture log close
		log using _output/`1'.log, replace
	
		use _data/replicationdata_2007-2010_log_dv, clear
		regress y_us x $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt replace

		use _data/replicationdata_2007-2008_log_dv, clear
		regress y_us x $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
	
		use _data/replicationdata_2009-2010_log_dv, clear
		regress y_us x $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
	
		log close
		
	}

	else if "`1'"=="TableB"{

		capture log close
		log using _output/`1'.log, replace
	
		use _data/replicationdata_2007-2010_unlog_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt replace
		estat endogenous
		estat firststage
		estat overid

		use _data/replicationdata_2007-2008_unlog_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		use _data/replicationdata_2009-2010_unlog_dv, clear
		ivregress 2sls y_us (x=z_*) $control1, robust 
		outreg2 x $control1 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		log close	
	
	}
	
	else if "`1'"=="TableC"{

		capture log close
		log using _output/`1'.log, replace
	
		use _data/replicationdata_2007-2010_log_dv, clear
		ivregress 2sls y_us (x_imputed=z_*) $control2, robust 
		outreg2 x_imputed $control2 using _output/`1'.txt, $opt replace
		estat endogenous
		estat firststage
		estat overid

		use _data/replicationdata_2007-2008_log_dv, clear
		ivregress 2sls y_us (x_imputed=z_*) $control2, robust 
		outreg2 x_imputed $control2 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		use _data/replicationdata_2009-2010_log_dv, clear
		ivregress 2sls y_us (x_imputed=z_*) $control2, robust 
		outreg2 x_imputed $control2 using _output/`1'.txt, $opt append
		estat endogenous
		estat firststage
		estat overid
	
		log close	
	
	}
		
	
end

myregress Table1_Table2
myregress Table3
myregress TableA
myregress TableB
myregress TableC


